@@ -8,7 +8,7 @@ SPVM::Sys::Socket::In_addr - struct in_addr in the C language
 
 =head1 Description
 
-The Sys::Socket::In_addr class in L<SPVM> represents L<struct in_addr|https://linux.die.net/man/3/inet_network> in the C language.
+Sys::Socket::In_addr class in L<SPVM> represents L<struct in_addr|https://linux.die.net/man/3/inet_network> in the C language.
 
 =head1 Usage
 
@@ -18,7 +18,7 @@ The Sys::Socket::In_addr class in L<SPVM> represents L<struct in_addr|https://li
 
 This class is a pointer class. The pointer the instance has is set to a L<struct in_addr|https://linux.die.net/man/3/inet_network> object.
 
-=head1 Inheritance
+=head1 Super Class
 
 L<Sys::Socket::In_addr_base|SPVM::Sys::Socket::In_addr_base>
 
